@@ -987,8 +987,8 @@ const static builder_schema data_schema = {
 const static builder_schema trust_schema = {
 	GENERATED_CLASS,
 	{ COMMON_ATTRS,
-	  { CKA_CERT_SHA1_HASH, CREATE },
-	  { CKA_CERT_MD5_HASH, CREATE },
+	  { CKA_NSS_CERT_SHA1_HASH, CREATE },
+	  { CKA_NSS_CERT_MD5_HASH, CREATE },
 	  { CKA_ISSUER, CREATE },
 	  { CKA_SUBJECT, CREATE },
 	  { CKA_SERIAL_NUMBER, CREATE },
@@ -996,18 +996,18 @@ const static builder_schema trust_schema = {
 	  { CKA_TRUST_CLIENT_AUTH, CREATE },
 	  { CKA_TRUST_EMAIL_PROTECTION, CREATE },
 	  { CKA_TRUST_CODE_SIGNING, CREATE },
-	  { CKA_TRUST_IPSEC_END_SYSTEM, CREATE },
-	  { CKA_TRUST_IPSEC_TUNNEL, CREATE },
-	  { CKA_TRUST_IPSEC_USER, CREATE },
+	  { CKA_NSS_TRUST_IPSEC_END_SYSTEM, CREATE },
+	  { CKA_NSS_TRUST_IPSEC_TUNNEL, CREATE },
+	  { CKA_NSS_TRUST_IPSEC_USER, CREATE },
 	  { CKA_TRUST_TIME_STAMPING, CREATE },
-	  { CKA_TRUST_DIGITAL_SIGNATURE, CREATE },
-	  { CKA_TRUST_NON_REPUDIATION, CREATE },
-	  { CKA_TRUST_KEY_ENCIPHERMENT, CREATE },
-	  { CKA_TRUST_DATA_ENCIPHERMENT, CREATE },
-	  { CKA_TRUST_KEY_AGREEMENT, CREATE },
-	  { CKA_TRUST_KEY_CERT_SIGN, CREATE },
-	  { CKA_TRUST_CRL_SIGN, CREATE },
-	  { CKA_TRUST_STEP_UP_APPROVED, CREATE },
+	  { CKA_NSS_TRUST_DIGITAL_SIGNATURE, CREATE },
+	  { CKA_NSS_TRUST_NON_REPUDIATION, CREATE },
+	  { CKA_NSS_TRUST_KEY_ENCIPHERMENT, CREATE },
+	  { CKA_NSS_TRUST_DATA_ENCIPHERMENT, CREATE },
+	  { CKA_NSS_TRUST_KEY_AGREEMENT, CREATE },
+	  { CKA_NSS_TRUST_KEY_CERT_SIGN, CREATE },
+	  { CKA_NSS_TRUST_CRL_SIGN, CREATE },
+	  { CKA_NSS_TRUST_STEP_UP_APPROVED, CREATE },
 	  { CKA_ID, CREATE },
 	  { CKA_INVALID },
 	}, common_populate
@@ -1270,13 +1270,13 @@ build_trust_object_ku (p11_builder *builder,
 		CK_ATTRIBUTE_TYPE type;
 		unsigned int ku;
 	} ku_attribute_map[] = {
-		{ CKA_TRUST_DIGITAL_SIGNATURE, P11_KU_DIGITAL_SIGNATURE },
-		{ CKA_TRUST_NON_REPUDIATION, P11_KU_NON_REPUDIATION },
-		{ CKA_TRUST_KEY_ENCIPHERMENT, P11_KU_KEY_ENCIPHERMENT },
-		{ CKA_TRUST_DATA_ENCIPHERMENT, P11_KU_DATA_ENCIPHERMENT },
-		{ CKA_TRUST_KEY_AGREEMENT, P11_KU_KEY_AGREEMENT },
-		{ CKA_TRUST_KEY_CERT_SIGN, P11_KU_KEY_CERT_SIGN },
-		{ CKA_TRUST_CRL_SIGN, P11_KU_CRL_SIGN },
+		{ CKA_NSS_TRUST_DIGITAL_SIGNATURE, P11_KU_DIGITAL_SIGNATURE },
+		{ CKA_NSS_TRUST_NON_REPUDIATION, P11_KU_NON_REPUDIATION },
+		{ CKA_NSS_TRUST_KEY_ENCIPHERMENT, P11_KU_KEY_ENCIPHERMENT },
+		{ CKA_NSS_TRUST_DATA_ENCIPHERMENT, P11_KU_DATA_ENCIPHERMENT },
+		{ CKA_NSS_TRUST_KEY_AGREEMENT, P11_KU_KEY_AGREEMENT },
+		{ CKA_NSS_TRUST_KEY_CERT_SIGN, P11_KU_KEY_CERT_SIGN },
+		{ CKA_NSS_TRUST_CRL_SIGN, P11_KU_CRL_SIGN },
 		{ CKA_INVALID },
 	};
 
@@ -1358,9 +1358,9 @@ build_trust_object_eku (CK_ATTRIBUTE *object,
 		{ CKA_TRUST_CLIENT_AUTH, P11_OID_CLIENT_AUTH_STR },
 		{ CKA_TRUST_CODE_SIGNING, P11_OID_CODE_SIGNING_STR },
 		{ CKA_TRUST_EMAIL_PROTECTION, P11_OID_EMAIL_PROTECTION_STR },
-		{ CKA_TRUST_IPSEC_END_SYSTEM, P11_OID_IPSEC_END_SYSTEM_STR },
-		{ CKA_TRUST_IPSEC_TUNNEL, P11_OID_IPSEC_TUNNEL_STR },
-		{ CKA_TRUST_IPSEC_USER, P11_OID_IPSEC_USER_STR },
+		{ CKA_NSS_TRUST_IPSEC_END_SYSTEM, P11_OID_IPSEC_END_SYSTEM_STR },
+		{ CKA_NSS_TRUST_IPSEC_TUNNEL, P11_OID_IPSEC_TUNNEL_STR },
+		{ CKA_NSS_TRUST_IPSEC_USER, P11_OID_IPSEC_USER_STR },
 		{ CKA_TRUST_TIME_STAMPING, P11_OID_TIME_STAMPING_STR },
 		{ CKA_INVALID },
 	};
@@ -1433,10 +1433,10 @@ replace_nss_trust_object (p11_builder *builder,
 	CK_ATTRIBUTE generated = { CKA_X_GENERATED, &generatedv, sizeof (generatedv) };
 	CK_ATTRIBUTE invalid = { CKA_INVALID, };
 
-	CK_ATTRIBUTE md5_hash = { CKA_CERT_MD5_HASH, md5v, sizeof (md5v) };
-	CK_ATTRIBUTE sha1_hash = { CKA_CERT_SHA1_HASH, sha1v, sizeof (sha1v) };
+	CK_ATTRIBUTE md5_hash = { CKA_NSS_CERT_MD5_HASH, md5v, sizeof (md5v) };
+	CK_ATTRIBUTE sha1_hash = { CKA_NSS_CERT_SHA1_HASH, sha1v, sizeof (sha1v) };
 
-	CK_ATTRIBUTE step_up_approved = { CKA_TRUST_STEP_UP_APPROVED, &falsev, sizeof (falsev) };
+	CK_ATTRIBUTE step_up_approved = { CKA_NSS_TRUST_STEP_UP_APPROVED, &falsev, sizeof (falsev) };
 
 	CK_ATTRIBUTE_PTR label;
 	CK_ATTRIBUTE_PTR id;
